@@ -36,7 +36,7 @@
 #' }
 
 convert_dia <- function(d, code = "dia_code", code_type = "dia_code_type",  codes_to_find = NULL,
-                        collapse = NULL, code_time = "time_dia", time_type = "earliest", nThread = 4) {
+                        collapse = NULL, code_time = "time_dia", time_type = "earliest", nThread = parallel::detectCores()-1) {
 
   .SD=.N=.I=.GRP=.BY=.EACHI=..=..cols=.SDcols=i=j=time_to_db=..which_ids_to=..which_ids_from=combined=..collapse=. <- NULL
 
